#!/bin/bash
trap '
  trap - INT # restore default INT handler
  kill -s INT "$$"
' INT
MODEST="bash ../Modest/modes-slurm.sh"
MODESTEXTRA="--partition m610 --nodes 10 --cores 4 --thread-budget 16"
REPETITIONS=3
THREADS=4
EXT=.modest
run(){
	echo 
	for i in `seq 1 $REPETITIONS`
	do
		echo "${1}${EXT}: -M ${2} -L ${3} -E ${4} -W ${5} (${i}/${REPETITIONS})"
		$MODEST models/$1${EXT} $MODESTEXTRA --unsafe -D -Y -J $THREADS -W $5 -M $2 -L $3 -E $4 --collect-schedulers -O results/$1.$4.$2.$3.$i.txt
	done
}

# firewire.modest
run firewire RepresentativePTA 100 "TIME_BOUND=4000" 0.005
run firewire RepresentativePTA 1000 "TIME_BOUND=4000" 0.005
run firewire ZonePTA 100 "TIME_BOUND=4000" 0.005
run firewire ZonePTA 1000 "TIME_BOUND=4000" 0.005

# csmacd-n.modest
run csmacd-n RepresentativePTA 100 "N=2,K=1,D=1800" 0.005
run csmacd-n RepresentativePTA 1000 "N=2,K=1,D=1800" 0.005
run csmacd-n RepresentativePTA 100 "N=3,K=1,D=2700" 0.005
run csmacd-n RepresentativePTA 1000 "N=3,K=1,D=2700" 0.005
run csmacd-n RepresentativePTA 100 "N=4,K=1,D=3600" 0.005
run csmacd-n RepresentativePTA 1000 "N=4,K=1,D=3600" 0.005
run csmacd-n ZonePTA 100 "N=2,K=1,D=1800" 0.005
run csmacd-n ZonePTA 1000 "N=2,K=1,D=1800" 0.005
run csmacd-n ZonePTA 100 "N=3,K=1,D=2700" 0.005
run csmacd-n ZonePTA 1000 "N=3,K=1,D=2700" 0.005
run csmacd-n ZonePTA 100 "N=4,K=1,D=3600" 0.005
run csmacd-n ZonePTA 1000 "N=4,K=1,D=3600" 0.005

# wlan-large.modest
run wlan-large RepresentativePTA 100 "K=2" 0.001
run wlan-large RepresentativePTA 1000 "K=2" 0.001
run wlan-large ZonePTA 100 "K=2" 0.001
run wlan-large ZonePTA 1000 "K=2" 0.001
